@@ -1,11 +1,14 @@
+import copy
+
 from django import forms
 from django.conf import settings
 from django.forms.fields import FileField
 from django.template.defaultfilters import filesizeformat
 from django.utils.module_loading import import_string
 
+
 from . import dynamic_fields
-from . settings import *
+from . dynamic_fields import CaptchaField, CaptchaHiddenField
 from . utils import _split_choices_in_list_canc
 from . widgets import FormsetdWidget
 
@@ -25,10 +28,11 @@ class BaseDynamicForm(forms.Form):
         example:
 
         """
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)        
         self.fields = initial_fields or self.fields
         # Costruzione dinamica dei rimanenti fields del form
         if constructor_dict:
+            constructor_dict = copy.deepcopy(constructor_dict)
             for key, value in constructor_dict.items():
                 if ignore_format_field_name:
                     field_id = key
@@ -60,10 +64,14 @@ class BaseDynamicForm(forms.Form):
                                                                       field_required=field.required,
                                                                       prefix=name)
                         else:
-                            custom_widget = getattr(settings, 'CUSTOM_WIDGETS').get(field.__class__.__name__) \
-                                            if hasattr(settings, 'CUSTOM_WIDGETS') else None
-                            if custom_widget:
+                            custom_widget = getattr(settings, 'CUSTOM_WIDGETS', {}).get(field.__class__.__name__)
+                            # Questo consente al widget di essere dichiarato anche come Tipo e non sempre come Stringa
+                            if not custom_widget:
+                                custom_widget = self.fields[name].widget
+                            if isinstance(custom_widget, str):
                                 self.fields[name].widget = import_string(custom_widget)()
+                            else:
+                                self.fields[name].widget = custom_widget
                             if hasattr(field, 'choices'):
                                 self.fields[name].choices = getattr(field, 'choices')
 
@@ -123,6 +131,14 @@ class BaseDynamicForm(forms.Form):
 
     def clean(self, *args, **kwargs):
         cleaned_data = super().clean()
+
+        self.data = copy.deepcopy(self.data)
+        # CaPTCHA MUST BE ALWAYS RENEWED!
+        for field_name, field_obj in self.fields.items():
+            if type(field_obj) in (CaptchaField, CaptchaHiddenField):
+                self.data[field_name] = self.fields[field_name].widget.attrs['value']
+        # end CAPTCHA
+        
         for fname in self.fields:
             field = self.fields[fname]
             # formset is empty or not valid
